pygeodesy.deprecated.rhumbx

Package pygeodesy :: Package deprecated :: Module rhumbx |
[frames] | no frames]

# Module rhumbx

DEPRECATED on 2023.11.26, use module pygeodesy.rhumb.ekx instead.

Version: 25.05.12

Classes
| Rhumb Class to solve the direct and inverse rhumb problems, based on elliptic functions or Krüger series expansion
| RhumbLine Compute one or several points on a single rhumb line.

Variables
| __all__ = `_ALL_LAZY.rhumb_ekx`